@@ -18,9 +18,9 @@ def a_radians(a):
     if builtins.ANGLEMODE == DEGREES:
         return a * math.pi/180
     else:
-        return a  
-def clear_background(surface, width, height, color):
-    
+        return a
+        
+def clear_background(surface, width, height, color):    
     ctx = cairo.Context(surface)
     ctx.set_source_rgba(*bgra(color))
     ctx.rectangle(0, 0, width, height)
@@ -29,6 +29,7 @@ def clear_background(surface, width, height, color):
 def draw_line(surface, x1, y1, x2, y2):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -36,6 +37,7 @@ def draw_line(surface, x1, y1, x2, y2):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.set_line_width(thickness)
     ctx.move_to(x1, y1)
@@ -47,6 +49,7 @@ def draw_line(surface, x1, y1, x2, y2):
 def draw_rect(surface, x, y, width, height):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1 
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -54,6 +57,7 @@ def draw_rect(surface, x, y, width, height):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.rectangle(x, y, width, height)
     ctx.set_line_width(thickness)
@@ -67,6 +71,7 @@ def draw_rect(surface, x, y, width, height):
 def draw_polygon(surface, vertices):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -74,6 +79,7 @@ def draw_polygon(surface, vertices):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.move_to(*vertices[0])
     for n in range(1,len(vertices)):
@@ -90,12 +96,14 @@ def draw_polygon(surface, vertices):
 def draw_lines(surface, vertices):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
     thickness    = settings["stroke_weight"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.move_to(*vertices[0])
     for n in range(1,len(vertices)):
@@ -108,6 +116,7 @@ def draw_lines(surface, vertices):
 def draw_circle(surface, x, y, radius):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -116,6 +125,7 @@ def draw_circle(surface, x, y, radius):
     ctx = cairo.Context(surface)    
     ctx.translate(origin_x, origin_y)
     ctx.rotate(rotate_angle)
+    ctx.scale(scale_xy, scale_xy)
     ctx.arc(x, y, radius, 0, 2.0 * math.pi)
     ctx.set_line_width(thickness)
     if not(settings["no_fill"]):
@@ -128,6 +138,7 @@ def draw_circle(surface, x, y, radius):
 def draw_ellipse(surface, x, y, width, height):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -135,6 +146,7 @@ def draw_ellipse(surface, x, y, width, height):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)   
     radius = width/2
     scale_x = 1.0
@@ -154,6 +166,7 @@ def draw_ellipse(surface, x, y, width, height):
 def draw_arc(surface, x, y, width, height, angle1, angle2, mode):           
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -161,6 +174,7 @@ def draw_arc(surface, x, y, width, height, angle1, angle2, mode):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)   
     if mode == "pie":
         ctx.move_to(x, y)
@@ -184,6 +198,7 @@ def draw_arc(surface, x, y, width, height, angle1, angle2, mode):
 def draw_text(surface, txt, x, y, style):
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["text_outline"] 
@@ -193,6 +208,7 @@ def draw_text(surface, txt, x, y, style):
     font_size    = settings["text_size"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)    
     font_options = cairo.FontOptions()
     font_options.set_antialias(cairo.ANTIALIAS_DEFAULT)
@@ -235,6 +251,7 @@ def draw_spline(surface, curvevertices, mode):
     vertices =[]
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["text_outline"] 
@@ -244,6 +261,7 @@ def draw_spline(surface, curvevertices, mode):
     font_size    = settings["text_size"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.set_line_width(thickness)  
     vertices = list(curvevertices)
@@ -296,6 +314,7 @@ def draw_bezier(surface, x, y, bezier_vertices, mode):
   
     rotate_angle = a_radians(settings["rotate_amnt"])
     scale_xy     = settings["scale_amnt"]
+    if scale_xy == 0: scale_xy = 1
     origin_x     = settings["real_ox"]
     origin_y     = settings["real_oy"]
     stroke_color = settings["stroke_color"] 
@@ -303,6 +322,7 @@ def draw_bezier(surface, x, y, bezier_vertices, mode):
     fill_color   = settings["fill_color"]
     ctx = cairo.Context(surface)
     ctx.translate(origin_x, origin_y)
+    ctx.scale(scale_xy, scale_xy)
     ctx.rotate(rotate_angle)
     ctx.set_line_width(thickness)
     ctx.move_to(x, y)
