@@ -1,9 +1,6 @@
 import builtins
 from p5.constants import *
 
-pg_Screen = None
-clock = None
-
 builtins.mouseX         = 0
 builtins.mouseY         = 0
 builtins.pmouseX        = None
@@ -26,10 +23,14 @@ builtins.MILLIS         = 0
 builtins.frameCount     = 0
 builtins.ellipse_mode   = CENTER
 builtins.rect_mode      = CORNER
+builtins.pixels         = [] # store for pixels
 
+pg_Screen = None
+clock     = None
+# ----
+
+stack  = [] # store for settings
 
-# variables
-stack = [] # store for settings
 settings = {
     "fill_color"    : [255,255,255,255],
     "no_fill"       : False,
@@ -37,7 +38,7 @@ settings = {
     "stroke_weight" : 1,
     "stroke_color"  : [0,0,0,255],
     "rotate_amnt"   : 0,
-    "scale_amnt"    : 1,
+    "scale_amnt"    : 0,
     "text_size"     : 12,
     "text_font"     : "Arial",
     "text_bold"     : False,
